==> TclDevKit5.3.0.295349-linux-ix86-threaded.tar.gz: TclDevKit5.3.0.295349-linux-ix86-threaded/install_data.tcl <==
# -*- tcl -*-
# Copyright (C) 2001-2008 ActiveState Software Inc. Oct 13, 2011
#
# Information for the installer which is dependent on the chosen
# distribution. Original source of the information is the script
# "build/setvars.sh".
#
# ActiveState Tcl Dev Kit 5.3.0.295349 Linux/x86, Thu Oct 13 14:27:47 PDT 2011
#

global    AT
array set AT {
    build       {295349}
    NAME	{Tcl Dev Kit}
    PGROUP	{TclDevKit}
    dPGROUP	{Tcl Dev Kit}
    VERSION	5.3.0
    MATURITY	final
    Company	ActiveState
    url,about	http://www.activestate.com/activetcl-pro-studio
    url,update	http://www.activestate.com/activetcl-pro-studio
    url,help	http://www.activestate.com
    MODE	pro
    DISTC	tdk
    HELP	{TclDevKit.chm}
    BLD_PFXPATH  {/home/andreask/dbn/lba/GlobalBuildArena/builds/linux-ix86/out}
    BLD_EPFXPATH {/home/andreask/dbn/lba/GlobalBuildArena/builds/linux-ix86/out/linux-ix86}
    DEBUG        0
    THREADED     1
    tcl_VERSION  8.5
    ARCH         linux-ix86
    TDK_ATVERS   8.5.10.1
    true_MODE	 pro
}

if {[string equal $AT(MODE) normal]} {
    if {$AT(THREADED)} {set tSuffix "-thread" } else {set tSuffix ""}
    set AT(LOG) [file join \
	lib ppm log [string tolower $AT(PGROUP)]$AT(tcl_VERSION)$tSuffix install.log]
    unset tSuffix
} else {
    set AT(LOG) [file join \
	lib ppm log [string tolower $AT(PGROUP)] install.log]
}

# When this file is used by the uninstaller SCRIPT_DIR is not defined.

if {[info exists ::SCRIPT_DIR]} {
    set _welcome [file join $::SCRIPT_DIR install_welcome.txt]

    global WELCOME
    set    WELCOME [read [set fh [open $_welcome r]]][close $fh]
    unset _welcome
}

if {[string equal $::AT(MODE) direct]} {
    # For the purposes of the installation the 'direct' distribution
    # is the same as the 'normal' ActiveTcl one.
    set ::AT(MODE) normal
}

# ========================================

set ::AT(UNINSTALLER) uninstall
set ::AT(LICENSE)     license-tdk.terms
set ::AT(README)      README-tdk.txt
set ::AT(MANIFEST)    MANIFEST_tdk.txt

==> TclDevKit5.4.0.298612-linux-ix86-threaded.tar.gz: TclDevKit5.4.0.298612-linux-ix86-threaded/install_data.tcl <==
# -*- tcl -*-
# Copyright (C) 2001-2008 ActiveState Software Inc. Nov 04, 2014
#
# Information for the installer which is dependent on the chosen
# distribution. Original source of the information is the script
# "build/setvars.sh".
#
# ActiveState Tcl Dev Kit 5.4.0.298612 Linux/x86, Tue Nov 04 18:35:41 PST 2014
#

global    AT
array set AT {
    build       {298612}
    NAME	{Tcl Dev Kit}
    PGROUP	{TclDevKit}
    dPGROUP	{Tcl Dev Kit}
    VERSION	5.4.0
    MATURITY	final
    Company	ActiveState
    url,about	http://www.activestate.com/activetcl-pro-studio
    url,update	http://www.activestate.com/activetcl-pro-studio
    url,help	http://www.activestate.com
    MODE	pro
    DISTC	tdk
    HELP	{TclDevKit.chm}
    BLD_PFXPATH  {/home/andreask/dbn/lba/GlobalBuildArena/builds/linux-ix86/out}
    BLD_EPFXPATH {/home/andreask/dbn/lba/GlobalBuildArena/builds/linux-ix86/out/linux-ix86}
    DEBUG        0
    THREADED     1
    tcl_VERSION  8.5
    ARCH         linux-ix86
    TDK_ATVERS   8.5.17.0
    true_MODE	 pro
}

if {[string equal $AT(MODE) normal]} {
    if {$AT(THREADED)} {set tSuffix "-thread" } else {set tSuffix ""}
    set AT(LOG) [file join \
	lib ppm log [string tolower $AT(PGROUP)]$AT(tcl_VERSION)$tSuffix install.log]
    unset tSuffix
} else {
    set AT(LOG) [file join \
	lib ppm log [string tolower $AT(PGROUP)] install.log]
}

# When this file is used by the uninstaller SCRIPT_DIR is not defined.

if {[info exists ::SCRIPT_DIR]} {
    set _welcome [file join $::SCRIPT_DIR install_welcome.txt]

    global WELCOME
    set    WELCOME [read [set fh [open $_welcome r]]][close $fh]
    unset _welcome
}

if {[string equal $::AT(MODE) direct]} {
    # For the purposes of the installation the 'direct' distribution
    # is the same as the 'normal' ActiveTcl one.
    set ::AT(MODE) normal
}

# ========================================

set ::AT(UNINSTALLER)  uninstall
set ::AT(LICENSE)      license-tdk.terms
set ::AT(README)       README-tdk.txt
set ::AT(MANIFEST)     MANIFEST_tdk.txt
set ::AT(tcl_revision) e03818474b0c94354ffb8d2600d18a84a6fbecfe
set ::AT(tk_revision)  148dda7a6fa6be6b9196973f93beb31e28baab4b
